@@ -1,7 +1,7 @@
 import os 
 import sqlite3 
 
-__version__ = version = '2.1.6'
+__version__ = version = '2.1.6.2'
 
 SPECIAL_CHARS = r"~!#$%^&*()-=+[]\{}:;,._||" + r'"' + r"'<>?/0123456789"
 INSERT_SPECIAL_CHARS = r"0123456789" + r"-_()[]:/.,@#&" 
@@ -24,7 +24,8 @@ def __selroutine():
     Wordlists = {item[0] : item[1] for item in Wordlists}
  
 def __sroutine1():
-        
+    
+    import subprocess , sys   
     os.environ.update({'METEOR_DICEWARE_INTERNAL_WORDLIST_CREATION_PROCESS_UNDERWAY' :  '1' })   
     subprocess.call([sys.executable, '-m' , 'meteor_diceware.utils' , 'create' , 'main' , '-w'] , env = os.environ)
     subprocess.call([sys.executable , '-m' , 'meteor_diceware.utils' , 'edit' , 'main' , '-f' , os.path.join(ProgPath , 'actual_diceware.txt')] , env = os.environ )
